@@ -25,6 +25,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
+#include <time.h>
 
 #ifdef ENABLE_GNOME
 #include <libgnomeui/libgnomeui.h>
@@ -516,6 +517,8 @@ gst_tool_commit_async (GstTool             *tool,
 	user_data->func = func;
 	user_data->data = data;
 
+	tool->last_commit_time = time (NULL);
+
 	if (message)
 		gst_tool_show_report_window (tool, message);
 
@@ -565,21 +568,41 @@ configuration_object_changed (OobsObject *object,
 			      GstTool    *tool)
 {
 	gboolean do_update = TRUE;
+	time_t current_time;
+
+	current_time = time (NULL);
+
+	/* If we get ::changed shortly after having committed,
+	 * there's a good chance that the tool has been the
+	 * origin of the change. Of course there could be the
+	 * possibility that this isn't true, but will happen
+	 * quite rarely.
+	 */
+	if (current_time - tool->last_commit_time <= 2)
+		return;
 
 	if (gst_dialog_get_editing (tool->main_dialog)) {
-		GtkWidget *dialog;
+		GtkWidget *parent, *dialog;
 		gint response;
 
-		dialog = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
+		if (tool->configuration_changed_dialog)
+			return;
+
+		parent = gst_dialog_get_topmost_edit_dialog (tool->main_dialog);
+		dialog = gtk_message_dialog_new (GTK_WINDOW (parent),
 						 GTK_DIALOG_MODAL,
 						 GTK_MESSAGE_QUESTION,
 						 GTK_BUTTONS_YES_NO,
 						 _("The system configuration has potentially changed."));
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 							  _("Update content? This will lose any modification in course."));
+		tool->configuration_changed_dialog = dialog;
+
 		response = gtk_dialog_run (GTK_DIALOG (dialog));
 		do_update = (response == GTK_RESPONSE_YES);
-		gtk_widget_hide (dialog);
+
+		gtk_widget_destroy (dialog);
+		tool->configuration_changed_dialog = NULL;
 	}
 
 	if (do_update) {
@@ -588,6 +611,13 @@ configuration_object_changed (OobsObject *object,
 	}
 }
 
+static void
+configuration_object_committed (OobsObject *object,
+				GstTool    *tool)
+{
+	tool->last_commit_time = time (NULL);
+}
+
 void
 gst_tool_add_configuration_object (GstTool    *tool,
 				   OobsObject *object)
@@ -599,4 +629,6 @@ gst_tool_add_configuration_object (GstTool    *tool,
 
 	g_signal_connect (object, "changed",
 			  G_CALLBACK (configuration_object_changed), tool);
+	g_signal_connect (object, "committed",
+			  G_CALLBACK (configuration_object_committed), tool);
 }
