@@ -39,8 +39,9 @@ static GstDialogSignal signals [] = {
 	{ NULL }
 };
 
-static GstWidgetPolicy policies [] = {
-	{ NULL }
+static const gchar *policy_widgets [] = {
+	"services_list",
+	NULL
 };
 
 int 
@@ -49,8 +50,8 @@ main (int argc, char *argv[])
 	gst_init_tool ("services-admin", argc, argv, NULL);
 	tool = gst_services_tool_new ();
 
-	gst_dialog_set_widget_policies (tool->main_dialog, policies);
 	gst_dialog_connect_signals (tool->main_dialog, signals);
+	gst_dialog_require_authentication_for_widgets (tool->main_dialog, policy_widgets);
 	table_create ();
 	service_settings_table_create ();
 
