@@ -169,13 +169,19 @@ set_main_group (OobsUser *user)
 	OobsGroup *main_group, *group;
 	gboolean valid, found;
 
+	combo = gst_dialog_get_widget (tool->main_dialog, "user_settings_group");
+
+	if (!user) {
+		gtk_combo_box_set_active (GTK_COMBO_BOX (combo), -1);
+		return;
+	}
+
 	main_group = oobs_user_get_main_group (user);
 	found = FALSE;
 
 	if (!main_group)
 		main_group = oobs_users_config_get_default_group (OOBS_USERS_CONFIG (GST_USERS_TOOL (tool)->users_config));
 
-	combo = gst_dialog_get_widget (tool->main_dialog, "user_settings_group");
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
 	valid = gtk_tree_model_get_iter_first (model, &iter);
 
@@ -307,15 +313,14 @@ user_settings_dialog_new (OobsUser *user)
 {
 	OobsUsersConfig *config;
 	GtkWidget *dialog, *widget;
-	const gchar *login;
+	const gchar *login = NULL;
 	gchar *title;
 	gint uid;
 
 	dialog = gst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
-	login = (gchar*) oobs_user_get_login_name (user);
 
-	if (!login) {
-		g_object_set_data (G_OBJECT (dialog), "is_new", GINT_TO_POINTER (TRUE));
+	if (!user) {
+		g_object_set_data (G_OBJECT (dialog), "user", NULL);
 		gtk_window_set_title (GTK_WINDOW (dialog), _("New user account"));
 
 		config = OOBS_USERS_CONFIG (GST_USERS_TOOL (tool)->users_config);
@@ -329,8 +334,11 @@ user_settings_dialog_new (OobsUser *user)
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), uid);
 		setup_profiles_visibility (tool, TRUE);
 	} else {
-		g_object_set_data (G_OBJECT (dialog), "is_new", GINT_TO_POINTER (FALSE));
+		g_object_set_data_full (G_OBJECT (dialog), "user",
+					g_object_ref (user),
+					(GDestroyNotify) g_object_unref);
 
+		login = oobs_user_get_login_name (user);
 		title = g_strdup_printf (_("Account '%s' Properties"), login);
 		gtk_window_set_title (GTK_WINDOW (dialog), title);
 		g_free (title);
@@ -355,23 +363,23 @@ user_settings_dialog_new (OobsUser *user)
 	gtk_widget_set_sensitive (widget, (login == NULL));
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_real_name");
-	set_entry_text (widget, oobs_user_get_full_name (user));
+	set_entry_text (widget, (user) ? oobs_user_get_full_name (user) : NULL);
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_room_number");
-	set_entry_text (widget, oobs_user_get_room_number (user));
+	set_entry_text (widget, (user) ? oobs_user_get_room_number (user) : NULL);
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_wphone");
-	set_entry_text (widget, oobs_user_get_work_phone_number (user));
+	set_entry_text (widget, (user) ? oobs_user_get_work_phone_number (user) : NULL);
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_hphone");
-	set_entry_text (widget, oobs_user_get_home_phone_number (user));
+	set_entry_text (widget, (user) ? oobs_user_get_home_phone_number (user) : NULL);
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_passwd1");
-	set_entry_text (widget, (login) ? "password" : NULL);
+	set_entry_text (widget, NULL);
 	g_object_set_data (G_OBJECT (widget), "changed", GINT_TO_POINTER (FALSE));
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_passwd2");
-	set_entry_text (widget, (login) ? "password" : NULL);
+	set_entry_text (widget, NULL);
 
 	/* set always the first page */
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_notebook");
@@ -387,22 +395,15 @@ user_settings_dialog_new (OobsUser *user)
 	return dialog;
 }
 
-gboolean
-user_settings_dialog_user_is_new (void)
-{
-	GtkWidget *dialog;
-	gboolean is_new;
-
-	dialog = gst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
-	is_new = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dialog), "is_new"));
-
-	return is_new;
-}
-
 static gboolean
 is_user_root (OobsUser *user)
 {
-	const gchar *login = oobs_user_get_login_name (user);
+	const gchar *login;
+
+	if (!user)
+		return FALSE;
+
+	login = oobs_user_get_login_name (user);
 
 	if (!login)
 		return FALSE;
@@ -462,25 +463,23 @@ is_valid_name (const gchar *name)
 static void
 check_login (gchar **primary_text, gchar **secondary_text, gpointer data)
 {
-	OobsUser *user = OOBS_USER (data);
+	OobsUser *user;
 	GtkWidget *widget;
 	const gchar *login;
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_name");
 	login = gtk_entry_get_text (GTK_ENTRY (widget));
+	user = g_object_get_data (G_OBJECT (data), "user");
 
 	if (strlen (login) < 1) {
 		*primary_text = g_strdup (_("User name is empty"));
 		*secondary_text = g_strdup (_("A user name must be specified."));
-	} else if (is_user_root (user) && strcmp (login, "root") != 0) {
-		*primary_text = g_strdup (_("Administrator account's user name should not be modified"));
-	        *secondary_text = g_strdup (_("This would leave the system unusable."));
 	} else if (!is_valid_name (login)) {
 		*primary_text = g_strdup (_("User name has invalid characters"));
 		*secondary_text = g_strdup (_("Please set a valid user name consisting of "
 					      "a lower case letter followed by lower case "
 					      "letters and numbers."));
-	} else if (user_settings_dialog_user_is_new () && login_exists (login)) {
+	} else if (!user && login_exists (login)) {
 		*primary_text = g_strdup_printf (_("User name \"%s\" already exists"), login);
 		*secondary_text = g_strdup (_("Please select a different user name."));
 	}
@@ -489,7 +488,6 @@ check_login (gchar **primary_text, gchar **secondary_text, gpointer data)
 static void
 check_comments (gchar **primary_text, gchar **secondary_text, gpointer data)
 {
-	OobsUser *user = OOBS_USER (data);
 	GtkWidget *name, *room_number, *wphone, *hphone;
 	gchar *comment, *ch;
 
@@ -518,29 +516,34 @@ check_comments (gchar **primary_text, gchar **secondary_text, gpointer data)
 static void
 check_home (gchar **primary_text, gchar **secondary_text, gpointer data)
 {
-	OobsUser *user = OOBS_USER (data);
+	OobsUser *user;
 	GtkWidget *widget;
 	const gchar *home;
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_home");
 	home = gtk_entry_get_text (GTK_ENTRY (widget));
+	user = g_object_get_data (G_OBJECT (data), "user");
 
 	if (strlen (home) < 1 || !g_path_is_absolute (home)) {
-		*primary_text   = g_strdup (N_("Incomplete path in home directory"));
-		*secondary_text = g_strdup (N_("Please enter full path for home directory\n"
-					       "<span size=\"smaller\">i.e.: /home/john</span>."));
+		*primary_text   = g_strdup (_("Incomplete path in home directory"));
+		*secondary_text = g_strdup (_("Please enter full path for home directory\n"
+					      "<span size=\"smaller\">i.e.: /home/john</span>."));
+	} else if (!user && g_file_test (home, G_FILE_TEST_EXISTS)) {
+		*primary_text   = g_strdup (_("Home directory already exists"));
+		*secondary_text = g_strdup (_("Please enter a different home directory path."));
 	}
 }
 
 static void
 check_uid (gchar **primary_text, gchar **secondary_text, gpointer data)
 {
-	OobsUser *user = OOBS_USER (data);
+	OobsUser *user;
 	GtkWidget *widget;
 	gint uid;
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_uid");
 	uid = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
+	user = g_object_get_data (G_OBJECT (data), "user");
 
 	if (is_user_root (user) && uid != 0) {
 		*primary_text   = g_strdup (_("Administrator account's user ID should not be modified"));
@@ -551,7 +554,6 @@ check_uid (gchar **primary_text, gchar **secondary_text, gpointer data)
 static void
 check_shell (gchar **primary_text, gchar **secondary_text, gpointer data)
 {
-	OobsUser *user = OOBS_USER (data);
 	GtkWidget *widget;
 	const gchar *path;
 
@@ -568,25 +570,30 @@ check_shell (gchar **primary_text, gchar **secondary_text, gpointer data)
 static void
 check_password (gchar **primary_text, gchar **secondary_text, gpointer data)
 {
-	OobsUser *user = OOBS_USER (data);
+	OobsUser *user;
 	GtkWidget *widget;
 	const gchar *password, *confirmation;
+	gboolean changed = TRUE;
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_passwd_manual");
+	user = g_object_get_data (G_OBJECT (data), "user");
 
 	/* manual password? */
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget))) {
 		widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_passwd1");
 		password = gtk_entry_get_text (GTK_ENTRY (widget));
+		changed = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "changed"));
 
 		widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_passwd2");
 		confirmation = gtk_entry_get_text (GTK_ENTRY (widget));
-	}
-	else {
+	} else {
 		widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_random_passwd");
 		password = confirmation = gtk_entry_get_text (GTK_ENTRY (widget));
 	}
 
+	if (user && !changed)
+		return;
+
 	if (strlen (password) < 6) {
 		*primary_text = g_strdup (_("Password is too short"));
 		*secondary_text = g_strdup (_("User passwords must be longer than 6 characters and preferably "
@@ -598,7 +605,7 @@ check_password (gchar **primary_text, gchar **secondary_text, gpointer data)
 }
 
 gint
-user_settings_dialog_run (GtkWidget *dialog, OobsUser *user)
+user_settings_dialog_run (GtkWidget *dialog)
 {
 	gint response;
 	gboolean valid;
@@ -616,9 +623,8 @@ user_settings_dialog_run (GtkWidget *dialog, OobsUser *user)
 
 	do {
 		response = gtk_dialog_run (GTK_DIALOG (dialog));
-
 		valid = (response == GTK_RESPONSE_OK) ?
-			test_battery_run (battery, GTK_WINDOW (dialog), user) : TRUE;
+			test_battery_run (battery, GTK_WINDOW (dialog), dialog) : TRUE;
 	} while (!valid);
 
 	gtk_widget_hide (dialog);
@@ -627,14 +633,28 @@ user_settings_dialog_run (GtkWidget *dialog, OobsUser *user)
 	return response;
 }
 
-void
-user_settings_dialog_get_data (OobsUser *user)
+OobsUser *
+user_settings_dialog_get_data (GtkWidget *dialog)
 {
 	GtkWidget *widget;
 	OobsGroup *group;
-	gchar *str;
+	OobsUser *user;
+	const gchar *str;
 	gboolean password_changed;
 
+	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_name");
+	str = gtk_entry_get_text (GTK_ENTRY (widget));
+	user = g_object_get_data (G_OBJECT (dialog), "user");
+
+	if (!str || !*str)
+		return NULL;
+
+	if (!user) {
+		user = oobs_user_new (str);
+		g_object_set_data_full (G_OBJECT (dialog), "user",
+					user, (GDestroyNotify) g_object_unref);
+	}
+
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_real_name");
 	oobs_user_set_full_name (user, gtk_entry_get_text (GTK_ENTRY (widget)));
 
@@ -675,6 +695,8 @@ user_settings_dialog_get_data (OobsUser *user)
 	g_object_unref (group);
 
 	privileges_table_save (user);
+
+	return user;
 }
 
 void
